
typedef struct LArgs
  {
    char call[1024];
    char command[1024];
    unsigned long flags, attrib, workspace, stack, decoration;
    unsigned long pause;
    Bool iconic;
  } LArgs;


Window getleader(Window client);
LArgs arginit(int argc, char **argv);


int checkcommand(Window leader, LArgs launchargs);
int launch(LArgs launchargs);
void hintwin(Window root, Window win, LArgs launchargs);

unsigned long getmilliseconds(void);

void usage(void);
void die(char * error);
int xerror(Display *display, XErrorEvent *error);

